@@ -49,6 +49,7 @@
 		var $_bBody;			// no HTML BODY shown on the report
 		var $_bDeleteXML;		// if needs to delete the XML file after using it
 		var $_oError;
+		var $_oInput;			// input plugins
 
 		/***************************************************************************
 		*																									*
@@ -84,6 +85,7 @@
 			$this->_bBody				= true;
 			$this->_bDeleteXML		= false;
 			$this->_oError				= new PHPReportsErrorTr();
+			$this->_oInput				= Array();
 
 			/*
 				Now we get the XSLT processor
@@ -148,6 +150,19 @@
 				// if the database connection is null, open it
 				if(is_null($this->_oCon))
 					$this->_oCon = @PHPReportsDBI::db_connect(Array($this->sUser,$this->sPass,$this->sCon,$this->sDatabase)) or $oError->showMsg("REFUSEDCON");
+
+				// if there are some input filters ...
+				if($this->_oInput){
+					foreach($this->_oInput as $oFilter){
+						$oFilter->setConnection($this->_oCon);
+						$oFilter->setSQL(trim($this->sSQL));
+						$this->sSQL = trim($oFilter->run());
+					}
+					// there is no need to run the filters again
+					$this->_oInput = null;
+				}
+
+				// run the query
 				$this->_oQuery = @PHPReportsDBI::db_query($this->_oCon,trim($this->sSQL)) or $oError->showMsg("QUERYERROR");
 
 				// insert the column names
@@ -157,12 +172,13 @@
 				$iColNum = PHPREportsDBI::db_colnum($this->_oQuery);
 				for($i=1; $i<=$iColNum; $i++){
 					$sName				= PHPReportsDBI::db_columnName($this->_oQuery,$i);
-					$sReplacedNames  .= "<COL>".ucfirst(str_replace("_"," ",$sName))."</COL>";
-					$sNames			  .= "<COL TYPE=\"FIELD\">$sName</COL>";
+					$sExtra				= isNumericType(PHPReportsDBI::db_columnType($this->_oQuery,$i))?" ALIGN=\"RIGHT\"":"";
+					$sReplacedNames  .= "<COL CELLCLASS=\"bold\"$sExtra>".ucfirst(strtolower(str_replace("_"," ",$sName)))."</COL>";
+					$sNames			  .= "<COL TYPE=\"FIELD\"$sExtra>$sName</COL>";
 				}
 
 				// build the group info
-				$sGroup			= "<GROUP><HEADER><ROW><REPLACE_WITH_REPLACED_COLUMN_NAMES/></ROW></HEADER><FIELDS><ROW><REPLACE_WITH_COLUMN_NAMES/></ROW></FIELDS></GROUP>";
+				$sGroup			= "<GROUP REPRINT_HEADER_ON_PAGEBREAK='TRUE'><HEADER><ROW><REPLACE_WITH_REPLACED_COLUMN_NAMES/></ROW></HEADER><FIELDS><ROW><REPLACE_WITH_COLUMN_NAMES/></ROW></FIELDS></GROUP>";
 				$sGroup			= str_replace("<REPLACE_WITH_REPLACED_COLUMN_NAMES/>",$sReplacedNames,$sGroup);
 				$sGroup			= str_replace("<REPLACE_WITH_COLUMN_NAMES/>",$sNames,$sGroup);
 				$sFileContents = str_replace("<REPLACE_WITH_GROUP_INFO/>",$sGroup,$sFileContents);
@@ -214,7 +230,7 @@
 
 			// create the parameters keys array - with element numbers or element keys
 			$aKeys = null;
-			if(!is_null($this->_oParm)){
+			if(is_array($this->_oParm)){
 				$aKeys = array_keys($this->_oParm);
 				$iSize = sizeof($this->_oParm);
 				for($i=0; $i<$iSize; $i++){
@@ -268,6 +284,7 @@
 			
 			// set the database connection handle, if there is one
 			$oReport->setDatabaseConnection($this->_oCon);
+			$oReport->setInputFilters($this->_oInput);
 			$oReport->setQuery($this->_oQuery);
 
 			// run the generated class
@@ -606,6 +623,20 @@
 			return $oOut;
 		}
 
+		function addInputPlugin($sName_,$oGroupDesc_,$sGroupKey_,$oOptions_=null){
+			$sName  = ucwords(strtolower($sName_));
+			$sClass = "PHPReportInput$sName";
+			$sFullPath = $this->_sPath."/input/PHPReportInput$sName.php";
+			
+			// check if the required plugin exists
+			if(!file_exists($sFullPath))
+				$this->_oError->showMsg("NOPLUGIN",array($sName_,$sFullPath));
+			include $sFullPath; 
+
+			$oIn = new $sClass($oGroupDesc_,$sGroupKey_,$oOptions_);
+			array_push($this->_oInput,$oIn);
+		}
+
 		/******************************************************************************
 		*																										*
 		*	Output plugin for the final format														*
