@@ -321,6 +321,7 @@
 			$this->_aMsgs["NOPLUGIN"]["default"]		= "There is no <b>%s</b> output plugin (<b>%s</b>).";
 			$this->_aMsgs["NOLOAD"]["default"]			= "Could not find file <b>%s</b> for report loading.";
 			$this->_aMsgs["NOTEMPLATE"]["default"]		= "The template file <b>%s</b> was not found.";
+			$this->_aMsgs["INVALIDCON"]["default"]		= "Your database connection handle is not valid.";
 
 			// Brazilian Portuguese messages
 			$this->_aMsgs["OPS"]["pt_BR"]					= "OOOOPS, OCORREU UM ERRO AQUI.";
@@ -352,6 +353,7 @@
 			$this->_aMsgs["NOPLUGIN"]["pt_BR"]			= "O plugin de sada <b>%s</b> no existe (<b>%s</b>).";
 			$this->_aMsgs["NOLOAD"]["pt_BR"]				= "No encontrei o arquivo <b>%s</b> para carregar o relatrio.";
 			$this->_aMsgs["NOTEMPLATE"]["pt_BR"]		= "O arquivo de template <b>%s</b> no foi encontrado.";
+			$this->_aMsgs["INVALIDCON"]["pt_BR"]		= "A varivel da conexo com o banco de dados no  vlida. %s";
 		}
 
 		function showMsg($sMsg_=null,$oParms_=null){
@@ -386,4 +388,10 @@
 			exit();				
 		}
 	}
+
+	function isNumericType($sType=null){
+		$sStr = "NUMBER,NUMERIC,INT,DOUBLE,DECIMAL,REAL,TINY,SHORT,LONG,FLOAT,LONGLONG,INT24,YEAR,CID,FLOAT4,FLOAT8,INT2,".
+		"INT4,MONEY,OID,RELTIME,XID,DOUBLE PRECISION,SMALLINT,TINYINT,BIGINT,INT64,INT8,DATE,DATETIME";
+		return stristr($sStr,$sType);
+	}
 ?>
